@@ -17,6 +17,12 @@ def afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist):
         logger.info('已发布成功')
     elif r.status_code==400 and siteinfo.sitename=='zhuque' and 'code' in r.json() and 'TORRENT_ALREADY_UPLOAD' in r.json()['code']:
         return True,fileinfo+'种子发布失败,失败原因:种子已存在'
+    elif siteinfo.sitename=='zhuque' and r.status_code==400 and 'code' in r.json():
+        logger.warning('发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason)+'站点返回信息:'+r.json()['code'])
+        return True,fileinfo+' 站点发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason)
+    elif siteinfo.sitename=='zhuque' and 'code' in r.json():
+        logger.warning('发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason)+'站点返回信息:'+r.json()['code'])
+        return False,fileinfo+' 发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason)
     else:
         logger.warning('发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason))
         return False,fileinfo+' 发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason)
